﻿local easyLootLevels = {
	"Poor",
	"Common",
	"Uncommon",
	"Rare",
	"Epic",
	"Legendary",
	"Artifact",
	"Heirloom"
}

local panelName

local function eventHandler(self, event, ...)
  if (event=="LOOT_OPENED") then
  	local arg1 = ...
  	if(arg1 == 0 and EasyLootSettings.enabled) then
		EasyLoot_HandleLoot()
	elseif(not EasyLootSettings.enabled) then
			--DEFAULT_CHAT_FRAME:AddMessage("|cffffff00EasyLoot disabled")
  	end
  elseif (event=="START_LOOT_ROLL") then
  	if(EasyLootSettings.enabled) then
	  	local id, timer = ...
  		EasyLoot_HandleRoll(id)
  	end
  elseif (event=="CONFIRM_LOOT_ROLL") then
  	if(EasyLootSettings.enabled) then
  		local id, rolltype = ...
  		EasyLoot_HandleConfirmation(id, rolltype)
  	end
  elseif (event=="CONFIRM_DISENCHANT_ROLL") then
  	if(EasyLootSettings.enabled) then
  		local id, rolltype = ...
  		EasyLoot_HandleConfirmation(id, rolltype)
  	end
  elseif (event=="CHAT_MSG_LOOT") then
  	local message, sender, language, channelString, target, flags, _, channelNumber, channelName, _, _ = ...
	EasyLoot_HandleIncomingLoot(message)
  elseif (event=="VARIABLES_LOADED") then
  	EasyLootFilter:SetPoint("BOTTOMLEFT","UIParent", "BOTTOMLEFT", EasyLootSettings.dispx, EasyLootSettings.dispy);
	if(not (EasyLootLootList.greed)) then
		EasyLootLootList.greed = {}
		EasyLoot_GreedScrollBar_Update()
	end
	if(not (EasyLootLootList.greedkeep)) then
		EasyLootLootList.greedkeep = {}
		for i=1,getn(EasyLootLootList.greed),1 do
			EasyLootLootList.greedkeep[i] = false
		end
		EasyLoot_GreedScrollBar_Update()
	end
	if(not (EasyLootLootList.needkeep)) then
		EasyLootLootList.needkeep = {}
		for i=1,getn(EasyLootLootList.need),1 do
			EasyLootLootList.needkeep[i] = false
		end
		EasyLoot_NeedScrollBar_Update()
	end
	if(not EasyLootLootList.DisenchantRarity) then
		EasyLootLootList.DisenchantRarity = -1
	end
  end
end

function EasyLoot_OnLoad()
	local version = GetAddOnMetadata("EasyLoot", "Version")
	EasyLoot_SetVariables()
	--One of them allows SmartBuff to be closed with the Escape key
	tinsert(UISpecialFrames, "EasyLootFilter");
	UIPanelWindows["EasyLootFilter"] = nil;

	this:SetScript("OnEvent", eventHandler)
	this:RegisterEvent("VARIABLES_LOADED")

	SlashCmdList["EASYLOOT"] = function(msg)
		EasyLoot_SlashCommand(msg);
	end;
	SLASH_EASYLOOT1 = "/el"

	if( DEFAULT_CHAT_FRAME ) then
		DEFAULT_CHAT_FRAME:AddMessage("|cffffff00EasyLoot v"..version.." loaded")
	end
	UIErrorsFrame:AddMessage("EasyLoot v"..version.." AddOn loaded", 1.0, 1.0, 1.0, 1.0, UIERRORS_HOLD_TIME)
	this:RegisterEvent("LOOT_OPENED")
	this:RegisterEvent("START_LOOT_ROLL")
 	this:RegisterEvent("CONFIRM_LOOT_ROLL")
 	this:RegisterEvent("CONFIRM_DISENCHANT_ROLL")
	this:RegisterEvent("CHAT_MSG_LOOT")
end

function EasyLoot_SetVariables()
	if(not EasyLootSettings) then
		EasyLootSettings = {}
		EasyLootSettings.rarity = 1
		EasyLootSettings.quest = 1
		EasyLootSettings.enabled = true
		EasyLootSettings.freeforall = true
		EasyLootSettings.roundrobin = true
		EasyLootSettings.master = true
		EasyLootSettings.group = true
		EasyLootSettings.needbeforegreed = true
		EasyLootSettings.dispx = GetScreenWidth()/2 - 200;
		EasyLootSettings.dispy = GetScreenHeight()/2 - 200;
	end
	if(not EasyLootLootList) then
		EasyLootLootList = {}
		EasyLootLootList.ignore = {}
		EasyLootLootList.autoloot = {}
		EasyLootLootList.need = {}
		EasyLootLootList.needkeep = {}
		EasyLootLootList.greed = {}
		EasyLootLootList.greedkeep = {}
	end
end

function EasyLoot_SlashCommand(msg)
  if(msg) then
	local command = strlower(msg)
	if (command == "options") then
		InterfaceOptionsFrame_OpenToCategory(panelName);
	elseif(command == "show") then
		EasyLootFilter:Show()
	else
		EasyLootFilter:Hide()
	end
  end
end

function EasyLoot_OnDragStop()
	EasyLootSettings.dispx = this:GetLeft();
	EasyLootSettings.dispy = this:GetBottom();
end

function EasyLoot_HandleLoot()
	local numItems = GetNumLootItems()
	--DEFAULT_CHAT_FRAME:AddMessage("|cffffff00EasyLoot number of items:" .. numItems)
	for i=1,numItems do
		lootIcon, lootName, lootQuantity, rarity, locked = GetLootSlotInfo(i)
		if(not locked and EasyLootSettings[GetLootMethod()] and (rarity >= EasyLootSettings.rarity or not LootSlotIsItem(i) or EasyLoot_InTable(EasyLootLootList.autoloot, lootName)) and not(EasyLoot_InTable(EasyLootLootList.ignore, lootName))) then
			LootSlot(i)
		elseif(EasyLootSettings.quest) then
			local link = GetLootSlotLink(i)
			local _, _, _, _, _, itemType, itemSubType, _, _, _, _ = GetItemInfo(link)
			if(itemType == "Quest") then
				LootSlot(i)
			end
		end
	end
end

function EasyLoot_HandleRoll(id)
	local texture, name, count, quality, bindOnPickUp, canNeed, canDE = GetLootRollItemInfo(id)
  	--DEFAULT_CHAT_FRAME:AddMessage("|cffffff00EasyLoot item up for rolling: "..name.." Link: "..GetLootRollItemLink(id))
  	if(EasyLoot_InTable(EasyLootLootList.need, name) and canNeed) then
	  	--DEFAULT_CHAT_FRAME:AddMessage("|cffffff00EasyLoot item up for rolling: "..name.." canNeed: "..canNeed)
  		RollOnLoot(id, 1)
  	elseif (EasyLoot_InTable(EasyLootLootList.greed, name)) then
  		local index = EasyLoot_InTable(EasyLootLootList.greed, name)
  		if(type(EasyLootLootList.greed[index]) == "table") then
  			if(EasyLootLootList.greed[index].disenchant and canDE) then
			  	--DEFAULT_CHAT_FRAME:AddMessage("|cffffff00EasyLoot item up for rolling: "..name.." canDE: "..canDE.."DEing")
  				RollOnLoot(id, 3)
  			else
			  	--DEFAULT_CHAT_FRAME:AddMessage("|cffffff00EasyLoot item up for rolling: "..name.." greeding")
  				RollOnLoot(id, 2)
  			end
  		else
	  		RollOnLoot(id, 2)
  		end
  	elseif (EasyLootLootList.DisenchantRarity >= quality and canDE) then
  		RollOnLoot(id, 3)
  	elseif(EasyLootLootList.DisenchantRarity >= quality) then
  		RollOnLoot(id, 2)
  	end
end

function EasyLoot_HandleConfirmation(id, rolltype)
	local texture, name, count, quality, bindOnPickUp = GetLootRollItemInfo(id)
	--DEFAULT_CHAT_FRAME:AddMessage("|cffffff00EasyLoot confirm roll on "..name)
	if(rolltype == 1 and EasyLoot_InTable(EasyLootLootList.need, name)) then
		--DEFAULT_CHAT_FRAME:AddMessage("|cffffff00EasyLoot confirm "..name .." Need roll")
		ConfirmLootRoll(id, rolltype)
	elseif(rolltype == 2 and EasyLoot_InTable(EasyLootLootList.greed, name)) then
		--DEFAULT_CHAT_FRAME:AddMessage("|cffffff00EasyLoot confirm "..name .." Greed roll")
		ConfirmLootRoll(id, rolltype)
	elseif(rolltype == 3 and EasyLoot_InTable(EasyLootLootList.greed, name)) then
		local index = EasyLoot_InTable(EasyLootLootList.greed, name)
  		if(type(EasyLootLootList.greed[index]) == "table") then
  			if(EasyLootLootList.greed[index].disenchant and canDE) then
				--DEFAULT_CHAT_FRAME:AddMessage("|cffffff00EasyLoot confirm "..name .." DE roll listed")
				ConfirmLootRoll(id, rolltype)
			end
		end
	elseif(rolltype == 3 and not EasyLoot_InTable(EasyLootLootList.greed, name)) then
		if (EasyLootLootList.DisenchantRarity >= quality) then
			--DEFAULT_CHAT_FRAME:AddMessage("|cffffff00EasyLoot confirm "..name .." DE roll")
			ConfirmLootRoll(id, rolltype)
		end
	else
		--DEFAULT_CHAT_FRAME:AddMessage("|cffffff00EasyLoot confirm "..name .." confirmation on roll failed")
	end
end

function EasyLoot_HandleIncomingLoot(message)
	for i=1,getn(EasyLootLootList.need),1  do
		if(strmatch(message, "You receive .*"..EasyLootLootList.need[i]..".*")) then
			--DEFAULT_CHAT_FRAME:AddMessage("|cffffff00EasyLoot Match need")
			if(not EasyLootLootList.needkeep[i]) then
				tremove(EasyLootLootList.need, i)
				tremove(EasyLootLootList.needkeep, i)
				EasyLoot_NeedScrollBar_Update()
			end
			return
		end
	end
	for i=1, getn(EasyLootLootList.greed),1  do
		local name
		if (type(EasyLootLootList.greed) == "table") then
			name = EasyLootLootList.greed[i].name
		else
			name = EasyLootLootList.greed[i]
		end
		if(name and strmatch(message, "You receive .*"..name..".*")) then
			--DEFAULT_CHAT_FRAME:AddMessage("|cffffff00EasyLoot Match greed")
			if(not EasyLootLootList.greedkeep[i]) then
				tremove(EasyLootLootList.greed, i)
				tremove(EasyLootLootList.greedkeep, i)
				EasyLoot_GreedScrollBar_Update()
			end
			return
		end
	end
end

function EasyLoot_ConfigLoadOrCancel()
	EasyLootConfigFrameEnabled:SetChecked(EasyLootSettings.enabled)
	EasyLootConfigFrameFreeForAll:SetChecked(EasyLootSettings.freeforall)
	EasyLootConfigFrameRoundRobin:SetChecked(EasyLootSettings.roundrobin)
	EasyLootConfigFrameMaster:SetChecked(EasyLootSettings.master)
	EasyLootConfigFrameGroup:SetChecked(EasyLootSettings.group)
	EasyLootConfigFrameNeedBeforeGreed:SetChecked(EasyLootSettings.needbeforegreed)
	EasyLootConfigFrameQuest:SetChecked(EasyLootSettings.quest)
end

function EasyLootConfigFrame_OnLoad(panel)
	panelName = "EasyLoot " .. GetAddOnMetadata("EasyLoot", "Version")
	panel.name = panelName
	panel.okay = function(self)
		EasyLootConfig_Ok()
	end
	panel.cancel = function(self)
		EasyLoot_ConfigLoadOrCancel()
	end
	InterfaceOptions_AddCategory(panel);
end

function EasyLootConfig_Ok()
	EasyLootSettings.enabled=EasyLootConfigFrameEnabled:GetChecked()
	EasyLootSettings.freeforall=EasyLootConfigFrameFreeForAll:GetChecked()
	EasyLootSettings.roundrobin=EasyLootConfigFrameRoundRobin:GetChecked()
	EasyLootSettings.master=EasyLootConfigFrameMaster:GetChecked()
	EasyLootSettings.group=EasyLootConfigFrameGroup:GetChecked()
	EasyLootSettings.needbeforegreed = EasyLootConfigFrameNeedBeforeGreed:GetChecked()
	EasyLootSettings.quest = EasyLootConfigFrameQuest:GetChecked()
end

function EasyLoot_RarityDropdown_OnClick()
  local i = this:GetID()
  EasyLootSettings.rarity = i-1
  UIDropDownMenu_SetSelectedID(EasyLootConfigFrameComboRarity, i)
end

function EasyLoot_RarityDropdown_OnShow()
	UIDropDownMenu_Initialize(EasyLootConfigFrameComboRarity, EasyLoot_RarityDropdown_Initialize)
	UIDropDownMenu_SetSelectedID(EasyLootConfigFrameComboRarity, EasyLootSettings.rarity+1)
end

function EasyLoot_RarityDropdown_Initialize()
	local i;
	if(getn(easyLootLevels) > 0) then
		for i = 1, getn(easyLootLevels), 1 do
			local redComponent, greenComponent, blueComponent, hexColor = GetItemQualityColor(i-1)
			info = {
				text = hexColor..easyLootLevels[i];
				func = EasyLoot_RarityDropdown_OnClick;
			};
			UIDropDownMenu_AddButton(info);
			i = i + 1;
		end
	end
end

function EasyLoot_DisenchantRarityDropdown_OnClick()
  local i = this:GetID()
  if(i >= getn(easyLootLevels)) then
  	EasyLootLootList.DisenchantRarity = -1
  else
  	EasyLootLootList.DisenchantRarity = i-1
  end
  UIDropDownMenu_SetSelectedID(EasyLootFilterDisenchantComboRarity, i)
end

function EasyLoot_DisenchantRarityDropdown_OnShow()
	if(not EasyLootLootList.DisenchantRarity) then
		EasyLootLootList.DisenchantRarity = -1
	end
	UIDropDownMenu_Initialize(EasyLootFilterDisenchantComboRarity, EasyLoot_DisenchantRarityDropdown_Initialize)
	if(EasyLootLootList.DisenchantRarity == -1) then
		UIDropDownMenu_SetSelectedID(EasyLootFilterDisenchantComboRarity, getn(easyLootLevels)+1)
	else
		UIDropDownMenu_SetSelectedID(EasyLootFilterDisenchantComboRarity, EasyLootLootList.DisenchantRarity+1)
	end
end

function EasyLoot_DisenchantRarityDropdown_Initialize()
	local i;
	if(getn(easyLootLevels) > 0) then
		for i = 1, getn(easyLootLevels)+1, 1 do
			local redComponent, greenComponent, blueComponent, hexColor = GetItemQualityColor(i-1)
			local tempText
			if(i > getn(easyLootLevels)) then
				tempText = hexColor.."Disabled"
			else
				tempText = hexColor..easyLootLevels[i]
			end
			info = {
				text = tempText;
				func = EasyLoot_DisenchantRarityDropdown_OnClick;
			}
			UIDropDownMenu_AddButton(info)
			i = i + 1
		end
	end
end

function EasyLoot_InTable(t, val)
	for i=1, getn(t), 1 do
		local localValue
		if(type(t[i]) == "table") then
			localValue = t[i].name
		else
			localValue = t[i]
		end
  		if localValue == val then
		    return i
  		end
	end
	return false
end

function EasyLoot_InTable2(t, val)
	for _,v in pairs(t) do
		local localValue
		if(type(v) == "table") then
			localValue = v.name
		else
			localValue = v
		end
  		if localValue == val then
		    return true
  		end
	end
	return false
end

function EasyLoot_AutoLootScrollBar_Update()
	local line
	local lineplusoffset
	FauxScrollFrame_Update(EasyLootFilterAutoLootScrollFrame, getn(EasyLootLootList.autoloot), 5, 16)
	for line=1,5 do
		lineplusoffset = line + FauxScrollFrame_GetOffset(EasyLootFilterAutoLootScrollFrame)
		if lineplusoffset <= getn(EasyLootLootList.autoloot) then
			if(strlen(EasyLootLootList.autoloot[lineplusoffset]) > 12) then
				text = strsub(EasyLootLootList.autoloot[lineplusoffset],1,12).."..."
			else
				text = EasyLootLootList.autoloot[lineplusoffset]
			end
			getglobal("EasyLootAutoLootEntry"..line):SetText(text)
			getglobal("EasyLootAutoLootEntry"..line):Show()
		else
			getglobal("EasyLootAutoLootEntry"..line):Hide()
		end
	end
end

function EasyLoot_IgnoreScrollBar_Update()
	local line
	local lineplusoffset
	FauxScrollFrame_Update(EasyLootFilterIgnoreScrollFrame, getn(EasyLootLootList.ignore), 5, 16)
	for line=1,5 do
		lineplusoffset = line + FauxScrollFrame_GetOffset(EasyLootFilterIgnoreScrollFrame)
		if lineplusoffset <= getn(EasyLootLootList.ignore) then
			if(strlen(EasyLootLootList.ignore[lineplusoffset]) > 12) then
				text = strsub(EasyLootLootList.ignore[lineplusoffset],1,12).."..."
			else
				text = EasyLootLootList.autoloot[lineplusoffset]
			end
			getglobal("EasyLootIgnoreEntry"..line):SetText(text)
			getglobal("EasyLootIgnoreEntry"..line):Show()
		else
			getglobal("EasyLootIgnoreEntry"..line):Hide()
		end
	end
end

function EasyLoot_NeedScrollBar_Update()
	local line
	local lineplusoffset
	FauxScrollFrame_Update(EasyLootFilterNeedScrollFrame, getn(EasyLootLootList.need), 5, 16)
	for line=1,5 do
		lineplusoffset = line + FauxScrollFrame_GetOffset(EasyLootFilterNeedScrollFrame)
		if lineplusoffset <= getn(EasyLootLootList.need) then
			if(strlen(EasyLootLootList.need[lineplusoffset]) > 12) then
				text = strsub(EasyLootLootList.need[lineplusoffset],1,12).."..."
			else
				text = EasyLootLootList.need[lineplusoffset]
			end
			local keep = EasyLootLootList.needkeep[lineplusoffset]
			if(not keep) then
				keep = false
			end
			getglobal("EasyLootNeedEntry"..line):SetText(text)
			getglobal("EasyLootNeedEntry"..line):Show()
			getglobal("EasyLootNeedPermanent"..line):SetChecked(keep)
			getglobal("EasyLootNeedPermanent"..line):Show()
		else
			getglobal("EasyLootNeedEntry"..line):Hide()
			getglobal("EasyLootNeedPermanent"..line):Hide()
		end
	end
end

function EasyLoot_GreedScrollBar_Update()
	local line
	local lineplusoffset
	local name
	local disenchant
	FauxScrollFrame_Update(EasyLootFilterGreedScrollFrame, getn(EasyLootLootList.greed), 5, 16)
	for line=1,5 do
		lineplusoffset = line + FauxScrollFrame_GetOffset(EasyLootFilterGreedScrollFrame)
		if lineplusoffset <= getn(EasyLootLootList.greed) then
			if(type(EasyLootLootList.greed[lineplusoffset]) == "table") then
				name = EasyLootLootList.greed[lineplusoffset].name
				disenchant = EasyLootLootList.greed[lineplusoffset].disenchant
			else
				name = EasyLootLootList.greed[lineplusoffset]
				disenchant = nil
			end
			if(strlen(name) > 12) then
				text = strsub(name,1,12).."..."
			else
				text = name
			end
			local keep = EasyLootLootList.greedkeep[lineplusoffset]
			if(not keep) then
				keep = false
			end
			getglobal("EasyLootGreedEntry"..line):SetText(text)
			getglobal("EasyLootGreedEntry"..line):Show()
			getglobal("EasyLootGreedPermanent"..line):SetChecked(keep)
			getglobal("EasyLootGreedPermanent"..line):Show()
			getglobal("EasyLootGreedDisenchant"..line):SetChecked(disenchant)
			getglobal("EasyLootGreedDisenchant"..line):Show()
		else
			getglobal("EasyLootGreedEntry"..line):Hide()
			getglobal("EasyLootGreedPermanent"..line):Hide()
			getglobal("EasyLootGreedDisenchant"..line):Hide()
		end
	end
end

function EasyLoot_ListButtonClicked(button)
	local text = button:GetText()
	local name = button:GetName()
	if(strmatch(name, "^EasyLootAutoLootEntry")) then
		local o = FauxScrollFrame_GetOffset(EasyLootFilterAutoLootScrollFrame)
		local line = tonumber(strmatch(name, "%d"))
		tremove(EasyLootLootList.autoloot, o+line)
		EasyLoot_AutoLootScrollBar_Update()
	elseif(strmatch(name, "^EasyLootIgnoreEntry")) then
		local o = FauxScrollFrame_GetOffset(EasyLootFilterIgnoreScrollFrame)
		local line = tonumber(strmatch(name, "%d"))
		tremove(EasyLootLootList.ignore, o+line)
		EasyLoot_IgnoreScrollBar_Update()
	elseif(strmatch(name, "^EasyLootNeedEntry")) then
		local o = FauxScrollFrame_GetOffset(EasyLootFilterNeedScrollFrame)
		local line = tonumber(strmatch(name, "%d"))
		tremove(EasyLootLootList.need, o+line)
		tremove(EasyLootLootList.needkeep, o+line)
		EasyLoot_NeedScrollBar_Update()
	elseif(strmatch(name, "^EasyLootGreedEntry")) then
		local o = FauxScrollFrame_GetOffset(EasyLootFilterGreedScrollFrame)
		local line = tonumber(strmatch(name, "%d"))
		tremove(EasyLootLootList.greed, o+line)
		tremove(EasyLootLootList.greedkeep, o+line)
		EasyLoot_GreedScrollBar_Update()
	end
end

function EasyLoot_ListPermanentClicked(self)
	local name = self:GetName()
	local checked = self:GetChecked()
	if(strmatch(name, "^EasyLootNeedPermanent")) then
		local o = FauxScrollFrame_GetOffset(EasyLootFilterNeedScrollFrame)
		local line = tonumber(strmatch(name, "%d"))
		EasyLootLootList.needkeep[o+line] = checked
		EasyLoot_NeedScrollBar_Update()
	elseif(strmatch(name, "^EasyLootGreedPermanent")) then
		local o = FauxScrollFrame_GetOffset(EasyLootFilterGreedScrollFrame)
		local line = tonumber(strmatch(name, "%d"))
		EasyLootLootList.greedkeep[o+line] = checked
		EasyLoot_GreedScrollBar_Update()
	end
end

function EasyLoot_ListDisenchantClicked(self)
	local name = self:GetName()
	local checked = self:GetChecked()
	if(strmatch(name, "^EasyLootGreedDisenchant")) then
		local o = FauxScrollFrame_GetOffset(EasyLootFilterGreedScrollFrame)
		local line = tonumber(strmatch(name, "%d"))
		if(type(EasyLootLootList.greed[o+line]) == "table") then
			EasyLootLootList.greed[o+line].disenchant = checked
		else
			local name = EasyLootLootList.greed[o+line]
			EasyLootLootList.greed[o+line] = {}
			EasyLootLootList.greed[o+line].name = name
			EasyLootLootList.greed[o+line].disenchant = checked
		end
		EasyLoot_GreedScrollBar_Update()
	end
end

function EasyLoot_SetHook()
	Old_ChatEdit_InsertLink = ChatEdit_InsertLink
	ChatEdit_InsertLink = function(text)
		ChatEdit_InsertLink = Old_ChatEdit_InsertLink
		return EasyLoot_InsertLink(text) or Old_ChatEdit_InsertLink(text)
	end
end

function EasyLoot_InsertLink(text)
	--DEFAULT_CHAT_FRAME:AddMessage(text)
	local _, _, _, _, _, _, _, _, _, _, _, _, _, Name = string.find(text, "|?c?f?f?(%x*)|?H?([^:]*):?(%d+):?(%d*):?(%d*):?(%d*):?(%d*):?(%d*):?(%-?%d*):?(%-?%d*):?(%d*)|?h?%[?([^%[%]]*)%]?|?h?|?r?")
	EasyLootFilterItem:SetText(Name)
	return true
end

function EasyLoot_AddAutoLoot()
	local itemName = EasyLootFilterItem:GetText()
	if(itemName and not (itemName=="")) then
		EasyLootLootList.autoloot[getn(EasyLootLootList.autoloot) + 1] = itemName
		EasyLoot_AutoLootScrollBar_Update()
		EasyLootFilterItem:SetText("")
	end
	EasyLootFilterItem:ClearFocus()
end

function EasyLoot_AddIgnore()
	local itemName = EasyLootFilterItem:GetText()
	if(itemName and not (itemName=="")) then
		EasyLootLootList.ignore[getn(EasyLootLootList.ignore) + 1] = itemName
		EasyLoot_IgnoreScrollBar_Update()
		EasyLootFilterItem:SetText("")
	end
	EasyLootFilterItem:ClearFocus()
end

function EasyLoot_AddNeed()
	local itemName = EasyLootFilterItem:GetText()
	if(itemName and not (itemName=="")) then
		EasyLootLootList.need[getn(EasyLootLootList.need) + 1] = itemName
		EasyLootLootList.needkeep[getn(EasyLootLootList.need)] = false
		EasyLoot_NeedScrollBar_Update()
		EasyLootFilterItem:SetText("")
	end
	EasyLootFilterItem:ClearFocus()
end

function EasyLoot_AddGreed()
	local itemName = EasyLootFilterItem:GetText()
	if(itemName and not (itemName=="")) then
		local n = getn(EasyLootLootList.greed) +1
		EasyLootLootList.greed[n] = {}
		EasyLootLootList.greed[n].name = itemName
		EasyLootLootList.greedkeep[n] = false
		EasyLoot_GreedScrollBar_Update()
		EasyLootFilterItem:SetText("")
	end
	EasyLootFilterItem:ClearFocus()
end
